const aliases = {
    "esc": "escape",
    "ins": "insert",
    "del": "delete",
    "up": "arrowup",
    "down": "arrowdown",
    "right": "arrowright",
    "left": "arrowleft",
    "pgup": "pageup",
    "pgdn": "pagedown",
    "break": "pause",
    "scroll": "scrolllock",
    "scrlk": "scrolllock",
    "prtscr": "printscreen",
    "win": "meta",
    "windows": "meta",
    "cmd": "meta",
    "command": "meta",
    "comma": ",",
    "period": ".",
    "quote": "\"",
    "singlequote": "'",
    "colon": ":",
    "semicolon": ";",
    "plus": "+",
    "minus": "-",
    "tilde": "~",
    "equal": "=",
    "slash": "/"
};
const control_keys = [
    "ctrlKey",
    "altKey",
    "shiftKey",
    "metaKey"
];
function registerHotkey(target, hotkey, handler, eventName = "keydown", options) {
    const info = describe(hotkey);
    if (typeof target === "string") {
        target = document.querySelector(target) ?? error(`No element found for selector '${target}'`);
    }
    return listen(target, eventName, function (e) {
        if (!options?.trusted || e.isTrusted) {
            if (!e.target?.closest("[data-hotkey-ignore]")) {
                if (info.code === e.code.toUpperCase()) {
                    if (control_keys.every(n => info[n] === e[n])) {
                        handler.call(this, e);
                    }
                }
            }
        }
    }, options);
}
function describe(hotkey) {
    const keys = hotkey.replace(/\s+/g, "").toLowerCase().split("+");
    const info = keys.reduce((data, k) => {
        k = aliases[k] ?? k;
        switch (k) {
            case "ctrl":
            case "alt":
            case "shift":
            case "meta":
                data[`${k}Key`] = true;
                break;
            default:
                k.length || error_invalid_key(hotkey);
                k = k.toUpperCase();
                data.code = k.length === 1 && k >= 'A' && k <= 'Z' ? `KEY${k}` : k;
                break;
        }
        return data;
    }, {
        code: "",
        ctrlKey: false,
        altKey: false,
        shiftKey: false,
        metaKey: false
    });
    info.code || error_invalid_key(hotkey);
    return info;
}
function listen(target, type, callback, options) {
    target.addEventListener(type, callback, options);
    return () => target.removeEventListener(type, callback, options);
}
function error_invalid_key(hotkey) {
    error(`Invalid hotkey: '${hotkey}'`);
}
function error(message) {
    throw new Error(message);
}

export { registerHotkey };